package ru.ulstu.tags.service;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import ru.ulstu.tags.model.TagDto;
import ru.ulstu.tags.repository.TagRepository;

import javax.transaction.Transactional;
import java.util.Set;
import java.util.stream.Collectors;

import static ru.ulstu.core.util.StreamApiUtils.convert;

@Service
public class TagService {

    private final TagRepository tagRepository;


    public TagService(TagRepository tagRepository) {

        this.tagRepository = tagRepository;
    }

    public Set<TagDto> saveOrCreate(Set<TagDto> tagDtos) {
        return tagDtos
                .stream()
                .map(tagDto -> {
                    return tagRepository.exists(tagDto.getId()) ? takeExist(tagDto) : create(tagDto);
                }).collect(Collectors.toSet());
    }

    @Transactional
    public TagDto takeExist(TagDto tagDto) {
        return tagRepository.findOne(tagDto.getId());
    }

    @Transactional
    public TagDto create(TagDto tagDto) {
        TagDto newTag = new TagDto();
        newTag.setTagName(tagDto.getTagName());
        newTag = tagRepository.save(newTag);
        return newTag;
    }

}
